@@ -70,17 +70,17 @@
 <context>
     <name>AlarmPickSelector</name>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="142"/>
+        <location filename="../AlarmPickSelector.cpp" line="152"/>
         <source>None</source>
         <translation>Keiner</translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="154"/>
+        <location filename="../AlarmPickSelector.cpp" line="164"/>
         <source>Exact</source>
         <translation>Genau</translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="156"/>
+        <location filename="../AlarmPickSelector.cpp" line="166"/>
         <source>%n hour(s) before</source>
         <translation>
             <numerusform>%n Stunde vorher</numerusform>
@@ -88,7 +88,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="157"/>
+        <location filename="../AlarmPickSelector.cpp" line="167"/>
         <source>%n minute(s) before</source>
         <translation>
             <numerusform>%n Minute vorher</numerusform>
@@ -96,7 +96,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="158"/>
+        <location filename="../AlarmPickSelector.cpp" line="168"/>
         <source>%n second(s) before</source>
         <translation>
             <numerusform>%n Sekunde vorher</numerusform>
@@ -104,7 +104,7 @@
         </translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="160"/>
+        <location filename="../AlarmPickSelector.cpp" line="170"/>
         <source>%1:%2:%3 before</source>
         <translation>%1:%2:%3 vorher</translation>
     </message>
@@ -277,6 +277,29 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>ChangeManager</name>
+    <message>
+        <location filename="../ChangeManager.cpp" line="239"/>
+        <source>Delete event?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="242"/>
+        <source>Delete task?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="245"/>
+        <source>Delete note?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="248"/>
+        <source>Delete component?</source>
+        <translation>Komponente löschen?</translation>
+    </message>
+</context>
 <context>
     <name>ColorPickDialog</name>
     <message>
@@ -316,17 +339,17 @@ tägig</translation>
 <context>
     <name>ComponentListWidget</name>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="72"/>
+        <location filename="../ComponentListWidget.cpp" line="71"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="73"/>
+        <location filename="../ComponentListWidget.cpp" line="72"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="74"/>
+        <location filename="../ComponentListWidget.cpp" line="73"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
@@ -334,17 +357,17 @@ tägig</translation>
 <context>
     <name>ComponentWidget</name>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="181"/>
+        <location filename="../week/ComponentWidget.cpp" line="183"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="182"/>
+        <location filename="../week/ComponentWidget.cpp" line="184"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="183"/>
+        <location filename="../week/ComponentWidget.cpp" line="185"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
@@ -497,31 +520,36 @@ tägig</translation>
     </message>
     <message>
         <location filename="../EventEditDialog.ui" line="118"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../EventEditDialog.ui" line="125"/>
         <source>Repeat</source>
         <translation>Wiederholen</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="128"/>
+        <location filename="../EventEditDialog.ui" line="135"/>
         <source>Calendar</source>
         <translation>Kalender</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="135"/>
+        <location filename="../EventEditDialog.ui" line="142"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="142"/>
+        <location filename="../EventEditDialog.ui" line="149"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="28"/>
+        <location filename="../EventEditDialog.cpp" line="30"/>
         <source>Edit event</source>
         <translation>Ereignis bearbeiten</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="31"/>
+        <location filename="../EventEditDialog.cpp" line="33"/>
         <source>New event</source>
         <translation>Neues Ereignis</translation>
     </message>
@@ -549,32 +577,32 @@ tägig</translation>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="179"/>
+        <location filename="../EventWindow.ui" line="182"/>
         <source>Previous event</source>
         <translation>Vorheriges Ereignis</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="184"/>
+        <location filename="../EventWindow.ui" line="187"/>
         <source>Next event</source>
         <translation>Nächstes Ereignis</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="189"/>
+        <location filename="../EventWindow.ui" line="192"/>
         <source>Edit event</source>
         <translation>Ereignis bearbeiten</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="194"/>
+        <location filename="../EventWindow.ui" line="197"/>
         <source>Delete event</source>
         <translation>Ereignis löschen</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="199"/>
+        <location filename="../EventWindow.ui" line="202"/>
         <source>Clone event</source>
         <translation>Ereignis duplizieren</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="204"/>
+        <location filename="../EventWindow.ui" line="207"/>
         <source>Automatic links</source>
         <translation>Automatische Verknüpfungen</translation>
     </message>
@@ -595,17 +623,17 @@ tägig</translation>
         <translation>Keine weiteren Ereignisse</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="269"/>
+        <location filename="../EventWindow.cpp" line="268"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="270"/>
+        <location filename="../EventWindow.cpp" line="269"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="271"/>
+        <location filename="../EventWindow.cpp" line="270"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
@@ -699,17 +727,17 @@ tägig</translation>
         <translation>Notizen</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="125"/>
+        <location filename="../JournalsPlug.cpp" line="124"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="126"/>
+        <location filename="../JournalsPlug.cpp" line="125"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="127"/>
+        <location filename="../JournalsPlug.cpp" line="126"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
@@ -785,16 +813,6 @@ tägig</translation>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../ChangeManager.cpp" line="180"/>
-        <source>Unable to edit birthdays</source>
-        <translation>Bearbeiten von Geburtstagen nicht möglich</translation>
-    </message>
-    <message>
-        <location filename="../ChangeManager.cpp" line="195"/>
-        <source>Delete component?</source>
-        <translation>Komponente löschen?</translation>
-    </message>
     <message>
         <location filename="../CWrapper.h" line="59"/>
         <source>Private</source>
@@ -814,62 +832,62 @@ tägig</translation>
         <translation>Wiederholung</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="27"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
         <source>Repeat</source>
         <translation>Wiederholung</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="37"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
         <source>View</source>
         <translation>Zeigen</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="58"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
         <source>Frequency</source>
         <translation>Frequenz</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="69"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
         <source>Daily</source>
         <translation>Täglich</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="74"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
         <source>Weekly</source>
         <translation>Wöchentlich</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="79"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
         <source>Monthly</source>
         <translation>Monatlich</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
         <source>Yearly</source>
         <translation>Jährlich</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="92"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
         <source>Interval</source>
         <translation>Intervall</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="116"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
         <source>Forever</source>
         <translation>Für immer</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="121"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
         <source>Until</source>
         <translation>Bis</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="126"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
         <source>Count</source>
         <translation>Anzahl</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="191"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
         <source>Week start</source>
         <translation>Wochenanfang</translation>
     </message>
@@ -961,32 +979,37 @@ tägig</translation>
         <translation>Einstellungen</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="20"/>
+        <location filename="../settings/SettingsDialog.ui" line="31"/>
         <source>Edit calendars</source>
         <translation>Kalender bearbeiten</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="30"/>
+        <location filename="../settings/SettingsDialog.ui" line="41"/>
         <source>Alarm tone</source>
         <translation>Alarmton</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="40"/>
+        <location filename="../settings/SettingsDialog.ui" line="51"/>
         <source>Delete events</source>
         <translation>Ereignisse löschen</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="50"/>
+        <location filename="../settings/SettingsDialog.ui" line="61"/>
         <source>Delete tasks</source>
         <translation>Aufgaben löschen</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="60"/>
+        <location filename="../settings/SettingsDialog.ui" line="71"/>
         <source>First day of week</source>
         <translation>Erster Tag der Woche</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="70"/>
+        <location filename="../settings/SettingsDialog.ui" line="81"/>
+        <source>Editable time zones</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/SettingsDialog.ui" line="88"/>
         <source>Date formats</source>
         <translation>Datumsformate</translation>
     </message>
@@ -996,13 +1019,13 @@ tägig</translation>
         <translation>Speichern</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.cpp" line="65"/>
+        <location filename="../settings/SettingsDialog.cpp" line="66"/>
         <source>Never</source>
         <translation>Nie</translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="67"/>
-        <location filename="../settings/SettingsDialog.cpp" line="69"/>
+        <location filename="../settings/SettingsDialog.cpp" line="68"/>
+        <location filename="../settings/SettingsDialog.cpp" line="70"/>
         <source>Older than %n week(s)</source>
         <translation>
             <numerusform>Älter als %n Woche</numerusform>
@@ -1010,7 +1033,7 @@ tägig</translation>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="71"/>
+        <location filename="../settings/SettingsDialog.cpp" line="72"/>
         <source>Older than %n month(s)</source>
         <translation>
             <numerusform>Älter als %n Monat</numerusform>
@@ -1018,7 +1041,7 @@ tägig</translation>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="73"/>
+        <location filename="../settings/SettingsDialog.cpp" line="74"/>
         <source>Older than %n year(s)</source>
         <translation>
             <numerusform>Älter als %n Jahr</numerusform>
@@ -1040,16 +1063,21 @@ tägig</translation>
     </message>
     <message>
         <location filename="../TodoEditDialog.ui" line="42"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TodoEditDialog.ui" line="49"/>
         <source>Calendar</source>
         <translation>Kalender</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="49"/>
+        <location filename="../TodoEditDialog.ui" line="56"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="56"/>
+        <location filename="../TodoEditDialog.ui" line="63"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
@@ -1107,17 +1135,17 @@ tägig</translation>
         <translation>Automatische Verknüpfungen</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="172"/>
+        <location filename="../TodoWindow.cpp" line="171"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="173"/>
+        <location filename="../TodoWindow.cpp" line="172"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="174"/>
+        <location filename="../TodoWindow.cpp" line="173"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
@@ -1126,6 +1154,7 @@ tägig</translation>
     <name>TodosPlug</name>
     <message>
         <location filename="../TodosPlug.cpp" line="34"/>
+        <location filename="../TodosPlug.cpp" line="329"/>
         <source>New task</source>
         <translation>Neue Aufgabe</translation>
     </message>
@@ -1136,31 +1165,36 @@ tägig</translation>
     </message>
     <message>
         <location filename="../TodosPlug.cpp" line="42"/>
+        <source>Group by calendar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TodosPlug.cpp" line="43"/>
         <source>Delete completed</source>
         <translation>Erledigte löschen</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="79"/>
+        <location filename="../TodosPlug.cpp" line="71"/>
         <source>Tasks</source>
         <translation>Aufgaben</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="203"/>
+        <location filename="../TodosPlug.cpp" line="332"/>
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="204"/>
+        <location filename="../TodosPlug.cpp" line="333"/>
         <source>Clone</source>
         <translation>Duplizieren</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="205"/>
+        <location filename="../TodosPlug.cpp" line="334"/>
         <source>Delete</source>
         <translation>Löschen</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="235"/>
+        <location filename="../TodosPlug.cpp" line="379"/>
         <source>Delete completed tasks from all calendars?</source>
         <translation>Erledigte Aufgaben aus allen Kalendern löschen?</translation>
     </message>
@@ -1238,4 +1272,22 @@ tägig</translation>
 Tag</translation>
     </message>
 </context>
+<context>
+    <name>ZonePickDialog</name>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="6"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="39"/>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.cpp" line="79"/>
+        <source>Current</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
