@@ -70,17 +70,17 @@
 <context>
     <name>AlarmPickSelector</name>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="142"/>
+        <location filename="../AlarmPickSelector.cpp" line="152"/>
         <source>None</source>
         <translation>Brak</translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="154"/>
+        <location filename="../AlarmPickSelector.cpp" line="164"/>
         <source>Exact</source>
         <translation>Punktualny</translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="156"/>
+        <location filename="../AlarmPickSelector.cpp" line="166"/>
         <source>%n hour(s) before</source>
         <translation>
             <numerusform>%n godzina przed</numerusform>
@@ -89,7 +89,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="157"/>
+        <location filename="../AlarmPickSelector.cpp" line="167"/>
         <source>%n minute(s) before</source>
         <translation>
             <numerusform>%n minuta przed</numerusform>
@@ -98,7 +98,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="158"/>
+        <location filename="../AlarmPickSelector.cpp" line="168"/>
         <source>%n second(s) before</source>
         <translation>
             <numerusform>%n sekunda przed</numerusform>
@@ -107,7 +107,7 @@
         </translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="160"/>
+        <location filename="../AlarmPickSelector.cpp" line="170"/>
         <source>%1:%2:%3 before</source>
         <translation>%1:%2:%3 przed</translation>
     </message>
@@ -281,6 +281,29 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>ChangeManager</name>
+    <message>
+        <location filename="../ChangeManager.cpp" line="239"/>
+        <source>Delete event?</source>
+        <translation>Usunąć zdarzenie?</translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="242"/>
+        <source>Delete task?</source>
+        <translation>Usunąć zadanie?</translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="245"/>
+        <source>Delete note?</source>
+        <translation>Usunąć notatkę?</translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="248"/>
+        <source>Delete component?</source>
+        <translation>Usunąć obiekt?</translation>
+    </message>
+</context>
 <context>
     <name>ColorPickDialog</name>
     <message>
@@ -320,17 +343,17 @@ dzień</translation>
 <context>
     <name>ComponentListWidget</name>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="72"/>
+        <location filename="../ComponentListWidget.cpp" line="71"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="73"/>
+        <location filename="../ComponentListWidget.cpp" line="72"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="74"/>
+        <location filename="../ComponentListWidget.cpp" line="73"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
@@ -338,17 +361,17 @@ dzień</translation>
 <context>
     <name>ComponentWidget</name>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="181"/>
+        <location filename="../week/ComponentWidget.cpp" line="183"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="182"/>
+        <location filename="../week/ComponentWidget.cpp" line="184"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="183"/>
+        <location filename="../week/ComponentWidget.cpp" line="185"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
@@ -504,31 +527,36 @@ dzień</translation>
     </message>
     <message>
         <location filename="../EventEditDialog.ui" line="118"/>
+        <source>Time zone</source>
+        <translation>Strefa czasowa</translation>
+    </message>
+    <message>
+        <location filename="../EventEditDialog.ui" line="125"/>
         <source>Repeat</source>
         <translation>Powtarzaj</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="128"/>
+        <location filename="../EventEditDialog.ui" line="135"/>
         <source>Calendar</source>
         <translation>Kalendarz</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="135"/>
+        <location filename="../EventEditDialog.ui" line="142"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="142"/>
+        <location filename="../EventEditDialog.ui" line="149"/>
         <source>Description</source>
         <translation>Opis</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="28"/>
+        <location filename="../EventEditDialog.cpp" line="30"/>
         <source>Edit event</source>
         <translation>Edytuj zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="31"/>
+        <location filename="../EventEditDialog.cpp" line="33"/>
         <source>New event</source>
         <translation>Nowe zdarzenie</translation>
     </message>
@@ -556,32 +584,32 @@ dzień</translation>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="179"/>
+        <location filename="../EventWindow.ui" line="182"/>
         <source>Previous event</source>
         <translation>Poprzednie zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="184"/>
+        <location filename="../EventWindow.ui" line="187"/>
         <source>Next event</source>
         <translation>Następne zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="189"/>
+        <location filename="../EventWindow.ui" line="192"/>
         <source>Edit event</source>
         <translation>Edytuj zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="194"/>
+        <location filename="../EventWindow.ui" line="197"/>
         <source>Delete event</source>
         <translation>Usuń zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="199"/>
+        <location filename="../EventWindow.ui" line="202"/>
         <source>Clone event</source>
         <translation>Powiel zdarzenie</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="204"/>
+        <location filename="../EventWindow.ui" line="207"/>
         <source>Automatic links</source>
         <translation>Automatyczne linki</translation>
     </message>
@@ -602,17 +630,17 @@ dzień</translation>
         <translation>Nie ma więcej zdarzeń</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="269"/>
+        <location filename="../EventWindow.cpp" line="268"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="270"/>
+        <location filename="../EventWindow.cpp" line="269"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="271"/>
+        <location filename="../EventWindow.cpp" line="270"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
@@ -709,17 +737,17 @@ dzień</translation>
         <translation>Notatki</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="125"/>
+        <location filename="../JournalsPlug.cpp" line="124"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="126"/>
+        <location filename="../JournalsPlug.cpp" line="125"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="127"/>
+        <location filename="../JournalsPlug.cpp" line="126"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
@@ -795,16 +823,6 @@ dzień</translation>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../ChangeManager.cpp" line="180"/>
-        <source>Unable to edit birthdays</source>
-        <translation>Nie można edytować urodzin</translation>
-    </message>
-    <message>
-        <location filename="../ChangeManager.cpp" line="195"/>
-        <source>Delete component?</source>
-        <translation>Usunąć obiekt?</translation>
-    </message>
     <message>
         <location filename="../CWrapper.h" line="59"/>
         <source>Private</source>
@@ -824,62 +842,62 @@ dzień</translation>
         <translation>Powtarzanie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="27"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
         <source>Repeat</source>
         <translation>Powtarzaj</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="37"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
         <source>View</source>
         <translation>Widok</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="58"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
         <source>Frequency</source>
         <translation>Częstotliwość</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="69"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
         <source>Daily</source>
         <translation>Dziennie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="74"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
         <source>Weekly</source>
         <translation>Tygodniowo</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="79"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
         <source>Monthly</source>
         <translation>Miesięcznie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
         <source>Yearly</source>
         <translation>Rocznie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="92"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
         <source>Interval</source>
         <translation>Odstęp</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="116"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
         <source>Forever</source>
         <translation>Wiecznie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="121"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
         <source>Until</source>
         <translation>Do</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="126"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
         <source>Count</source>
         <translation>Powtórzenia</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="191"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
         <source>Week start</source>
         <translation>Początek tygodnia</translation>
     </message>
@@ -971,32 +989,37 @@ dzień</translation>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="20"/>
+        <location filename="../settings/SettingsDialog.ui" line="31"/>
         <source>Edit calendars</source>
         <translation>Edytuj kalendarze</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="30"/>
+        <location filename="../settings/SettingsDialog.ui" line="41"/>
         <source>Alarm tone</source>
         <translation>Dźwięk alarmu</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="40"/>
+        <location filename="../settings/SettingsDialog.ui" line="51"/>
         <source>Delete events</source>
         <translation>Usuń zdarzenia</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="50"/>
+        <location filename="../settings/SettingsDialog.ui" line="61"/>
         <source>Delete tasks</source>
         <translation>Usuń zadania</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="60"/>
+        <location filename="../settings/SettingsDialog.ui" line="71"/>
         <source>First day of week</source>
         <translation>Pierwszy dzień tygodnia</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="70"/>
+        <location filename="../settings/SettingsDialog.ui" line="81"/>
+        <source>Editable time zones</source>
+        <translation>Edytowalne strefy czasowe</translation>
+    </message>
+    <message>
+        <location filename="../settings/SettingsDialog.ui" line="88"/>
         <source>Date formats</source>
         <translation>Format daty</translation>
     </message>
@@ -1006,13 +1029,13 @@ dzień</translation>
         <translation>Zapisz</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.cpp" line="65"/>
+        <location filename="../settings/SettingsDialog.cpp" line="66"/>
         <source>Never</source>
         <translation>Nigdy</translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="67"/>
-        <location filename="../settings/SettingsDialog.cpp" line="69"/>
+        <location filename="../settings/SettingsDialog.cpp" line="68"/>
+        <location filename="../settings/SettingsDialog.cpp" line="70"/>
         <source>Older than %n week(s)</source>
         <translation>
             <numerusform>Starsze niż %n tydzień</numerusform>
@@ -1021,7 +1044,7 @@ dzień</translation>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="71"/>
+        <location filename="../settings/SettingsDialog.cpp" line="72"/>
         <source>Older than %n month(s)</source>
         <translation>
             <numerusform>Starsze niż %n miesiąc</numerusform>
@@ -1030,7 +1053,7 @@ dzień</translation>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="73"/>
+        <location filename="../settings/SettingsDialog.cpp" line="74"/>
         <source>Older than %n year(s)</source>
         <translation>
             <numerusform>Starsze niż %n rok</numerusform>
@@ -1053,16 +1076,21 @@ dzień</translation>
     </message>
     <message>
         <location filename="../TodoEditDialog.ui" line="42"/>
+        <source>Time zone</source>
+        <translation>Strefa czasowa</translation>
+    </message>
+    <message>
+        <location filename="../TodoEditDialog.ui" line="49"/>
         <source>Calendar</source>
         <translation>Kalendarz</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="49"/>
+        <location filename="../TodoEditDialog.ui" line="56"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="56"/>
+        <location filename="../TodoEditDialog.ui" line="63"/>
         <source>Description</source>
         <translation>Opis</translation>
     </message>
@@ -1120,17 +1148,17 @@ dzień</translation>
         <translation>Automatyczne linki</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="172"/>
+        <location filename="../TodoWindow.cpp" line="171"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="173"/>
+        <location filename="../TodoWindow.cpp" line="172"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="174"/>
+        <location filename="../TodoWindow.cpp" line="173"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
@@ -1139,6 +1167,7 @@ dzień</translation>
     <name>TodosPlug</name>
     <message>
         <location filename="../TodosPlug.cpp" line="34"/>
+        <location filename="../TodosPlug.cpp" line="329"/>
         <source>New task</source>
         <translation>Nowe zadanie</translation>
     </message>
@@ -1149,31 +1178,36 @@ dzień</translation>
     </message>
     <message>
         <location filename="../TodosPlug.cpp" line="42"/>
+        <source>Group by calendar</source>
+        <translation>Grupuj według kalendarza</translation>
+    </message>
+    <message>
+        <location filename="../TodosPlug.cpp" line="43"/>
         <source>Delete completed</source>
         <translation>Usuń zakończone</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="79"/>
+        <location filename="../TodosPlug.cpp" line="71"/>
         <source>Tasks</source>
         <translation>Zadania</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="203"/>
+        <location filename="../TodosPlug.cpp" line="332"/>
         <source>Edit</source>
         <translation>Edytuj</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="204"/>
+        <location filename="../TodosPlug.cpp" line="333"/>
         <source>Clone</source>
         <translation>Powiel</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="205"/>
+        <location filename="../TodosPlug.cpp" line="334"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="235"/>
+        <location filename="../TodosPlug.cpp" line="379"/>
         <source>Delete completed tasks from all calendars?</source>
         <translation>Usunąć zakończone zadania ze wszystkich kalendarzy?</translation>
     </message>
@@ -1250,4 +1284,22 @@ dzień</translation>
         <translation>Cały dzień</translation>
     </message>
 </context>
+<context>
+    <name>ZonePickDialog</name>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="6"/>
+        <source>Time zone</source>
+        <translation>Strefa czasowa</translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="39"/>
+        <source>Search</source>
+        <translation>Szukaj</translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.cpp" line="79"/>
+        <source>Current</source>
+        <translation>Aktualna</translation>
+    </message>
+</context>
 </TS>
